==> auth-client-api-0.0.8-20201009.070551-12-sources.jar: com/xforceplus/phoenix/auth/client/model/MsAuthDrawBackResponse.java <==
package com.xforceplus.phoenix.auth.client.model;

import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.xforceplus.phoenix.auth.client.model.MsAuthDrawBackDetail;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.util.ArrayList;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonInclude;
import static com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL;
import com.fasterxml.jackson.annotation.JsonIgnore;
import javax.validation.constraints.*;

/**
 * 返回对象
 */
@ApiModel(description = "返回对象")

@JsonInclude(NON_NULL)
public class MsAuthDrawBackResponse {
  @JsonProperty("code")
  private Integer code = null;

  @JsonProperty("message")
  private String message = null;

  @JsonProperty("result")
  private List<MsAuthDrawBackDetail> result = new ArrayList<MsAuthDrawBackDetail>();

  @JsonIgnore
  public MsAuthDrawBackResponse code(Integer code) {
    this.code = code;
    return this;
  }

   /**
   * 1-成功，0-失败
   * @return code
  **/
  @ApiModelProperty(value = "1-成功，0-失败")
  public Integer getCode() {
    return code;
  }

  public void setCode(Integer code) {
    this.code = code;
  }

  @JsonIgnore
  public MsAuthDrawBackResponse message(String message) {
    this.message = message;
    return this;
  }

   /**
   * return message
   * @return message
  **/
  @ApiModelProperty(value = "return message")
  public String getMessage() {
    return message;
  }

  public void setMessage(String message) {
    this.message = message;
  }

  @JsonIgnore
  public MsAuthDrawBackResponse result(List<MsAuthDrawBackDetail> result) {
    this.result = result;
    return this;
  }

  public MsAuthDrawBackResponse addResultItem(MsAuthDrawBackDetail resultItem) {
    this.result.add(resultItem);
    return this;
  }

   /**
   * Get result
   * @return result
  **/
  @ApiModelProperty(value = "")
  public List<MsAuthDrawBackDetail> getResult() {
    return result;
  }

  public void setResult(List<MsAuthDrawBackDetail> result) {
    this.result = result;
  }


  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    MsAuthDrawBackResponse authDrawBackResponse = (MsAuthDrawBackResponse) o;
    return Objects.equals(this.code, authDrawBackResponse.code) &&
        Objects.equals(this.message, authDrawBackResponse.message) &&
        Objects.equals(this.result, authDrawBackResponse.result);
  }

  @Override
  public int hashCode() {
    return Objects.hash(code, message, result);
  }


  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class MsAuthDrawBackResponse {\n");
    
    sb.append("    code: ").append(toIndentedString(code)).append("\n");
    sb.append("    message: ").append(toIndentedString(message)).append("\n");
    sb.append("    result: ").append(toIndentedString(result)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }

}

==> auth-client-api-0.0.8-20201105.085145-50-sources.jar: com/xforceplus/phoenix/auth/client/model/MsAuthDrawBackResponse.java <==
package com.xforceplus.phoenix.auth.client.model;

import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.xforceplus.phoenix.auth.client.model.MsAuthDrawBackDetail;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.util.ArrayList;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonInclude;
import static com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL;
import com.fasterxml.jackson.annotation.JsonIgnore;
import javax.validation.constraints.*;

/**
 * 返回对象
 */
@ApiModel(description = "返回对象")

@JsonInclude(NON_NULL)
public class MsAuthDrawBackResponse {
  @JsonProperty("code")
  private Integer code = null;

  @JsonProperty("message")
  private String message = null;

  @JsonProperty("total")
  private Integer total = null;

  @JsonProperty("result")
  private List<MsAuthDrawBackDetail> result = new ArrayList<MsAuthDrawBackDetail>();

  @JsonIgnore
  public MsAuthDrawBackResponse code(Integer code) {
    this.code = code;
    return this;
  }

   /**
   * 1-成功，0-失败
   * @return code
  **/
  @ApiModelProperty(value = "1-成功，0-失败")
  public Integer getCode() {
    return code;
  }

  public void setCode(Integer code) {
    this.code = code;
  }

  @JsonIgnore
  public MsAuthDrawBackResponse message(String message) {
    this.message = message;
    return this;
  }

   /**
   * return message
   * @return message
  **/
  @ApiModelProperty(value = "return message")
  public String getMessage() {
    return message;
  }

  public void setMessage(String message) {
    this.message = message;
  }

  @JsonIgnore
  public MsAuthDrawBackResponse total(Integer total) {
    this.total = total;
    return this;
  }

   /**
   * 数量
   * @return total
  **/
  @ApiModelProperty(value = "数量")
  public Integer getTotal() {
    return total;
  }

  public void setTotal(Integer total) {
    this.total = total;
  }

  @JsonIgnore
  public MsAuthDrawBackResponse result(List<MsAuthDrawBackDetail> result) {
    this.result = result;
    return this;
  }

  public MsAuthDrawBackResponse addResultItem(MsAuthDrawBackDetail resultItem) {
    this.result.add(resultItem);
    return this;
  }

   /**
   * Get result
   * @return result
  **/
  @ApiModelProperty(value = "")
  public List<MsAuthDrawBackDetail> getResult() {
    return result;
  }

  public void setResult(List<MsAuthDrawBackDetail> result) {
    this.result = result;
  }


  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    MsAuthDrawBackResponse authDrawBackResponse = (MsAuthDrawBackResponse) o;
    return Objects.equals(this.code, authDrawBackResponse.code) &&
        Objects.equals(this.message, authDrawBackResponse.message) &&
        Objects.equals(this.total, authDrawBackResponse.total) &&
        Objects.equals(this.result, authDrawBackResponse.result);
  }

  @Override
  public int hashCode() {
    return Objects.hash(code, message, total, result);
  }


  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class MsAuthDrawBackResponse {\n");
    
    sb.append("    code: ").append(toIndentedString(code)).append("\n");
    sb.append("    message: ").append(toIndentedString(message)).append("\n");
    sb.append("    total: ").append(toIndentedString(total)).append("\n");
    sb.append("    result: ").append(toIndentedString(result)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }

}
